from tkinter import*

print("I TOLD YOU THIS IS NOTHING!")

window = Tk()
window.title("Nothing")
canvas = Canvas(bg="red")
canvas.pack()
lable = Label(text="I TOLD YOU THIS IS NOTHING!")
lable.pack()
window.mainloop()



import setuptools

readme = "jhbjhbghujhbgyuhgvhyhbvgyujhbvgyuujhbghyjnbvgyjhgyujhgyujhgtyuiujhyikjhuy78uhgyt7yt67ygftygtyuygtyyug"

setuptools.setup(
    name="absolutlynothing",
    version="1.0.0",
    author="Nathan Adams",
    description="Nothing",
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        ],

    python_requires='>=3.6',
    py_modules=["absolutlynothing"],
    install_requires=[]
    )
